Function llvm_mlir_sys::mlirBlockArgumentGetArgNumber
source · Expand description
Returns the position of the value in the argument list of its block.
Returns the position of the value in the argument list of its block.