Function llvm_mlir_sys::mlirBlockArgumentGetOwner
source · Expand description
Returns the block in which this value is defined as an argument. Asserts if the value is not a block argument.
Returns the block in which this value is defined as an argument. Asserts if the value is not a block argument.