Function llvm_mlir_sys::mlirBlockEqual
source · Expand description
Checks whether two blocks handles point to the same block. This does not perform deep comparison.
Checks whether two blocks handles point to the same block. This does not perform deep comparison.