Function llvm_mlir_sys::mlirBlockGetNextInRegion
source · Expand description
Returns the block immediately following the given block in its parent region.
Returns the block immediately following the given block in its parent region.