Function llvm_mlir_sys::mlirComplexTypeGet
source · Expand description
Creates a complex type with the given element type in the same context as the element type. The type is owned by the context.
Creates a complex type with the given element type in the same context as the element type. The type is owned by the context.