Function llvm_mlir_sys::mlirContextCreate
source · pub unsafe extern "C" fn mlirContextCreate() -> MlirContextExpand description
Creates an MLIR context and transfers its ownership to the caller.
pub unsafe extern "C" fn mlirContextCreate() -> MlirContextCreates an MLIR context and transfers its ownership to the caller.