pub unsafe extern "C" fn mlirContextLoadAllAvailableDialects(
context: MlirContext
)Expand description
Eagerly loads all available dialects registered with a context, making them available for use for IR construction.
pub unsafe extern "C" fn mlirContextLoadAllAvailableDialects(
context: MlirContext
)Eagerly loads all available dialects registered with a context, making them available for use for IR construction.