Function llvm_mlir_sys::mlirOpResultGetResultNumber
source · Expand description
Returns the position of the value in the list of results of the operation that produced it.
Returns the position of the value in the list of results of the operation that produced it.