pub unsafe extern "C" fn mlirOperationRemoveAttributeByName(
op: MlirOperation,
name: MlirStringRef
) -> boolExpand description
Removes an attribute by name. Returns false if the attribute was not found and true if removed.
pub unsafe extern "C" fn mlirOperationRemoveAttributeByName(
op: MlirOperation,
name: MlirStringRef
) -> boolRemoves an attribute by name. Returns false if the attribute was not found and true if removed.