Function llvm_mlir_sys::mlirQuantizedTypeGetExpressedType
source · Expand description
Gets the original type approximated by the given quantized type.
Gets the original type approximated by the given quantized type.