Function llvm_mlir_sys::mlirShapedTypeIsDynamicDim
source · Expand description
Checks wither the dim-th dimension of the given shaped type is dynamic.
Checks wither the dim-th dimension of the given shaped type is dynamic.