pub unsafe extern "C" fn mlirSparseTensorEncodingAttrGetDimLevelType(
attr: MlirAttribute,
pos: isize
) -> MlirSparseTensorDimLevelTypeExpand description
Returns a specified dim level type in a sparse_tensor.encoding attribute.
pub unsafe extern "C" fn mlirSparseTensorEncodingAttrGetDimLevelType(
attr: MlirAttribute,
pos: isize
) -> MlirSparseTensorDimLevelTypeReturns a specified dim level type in a sparse_tensor.encoding attribute.