pub unsafe extern "C" fn mlirSparseTensorEncodingGetNumDimLevelTypes(
attr: MlirAttribute
) -> isizeExpand description
Returns the number of dim level types in a sparse_tensor.encoding attribute.
pub unsafe extern "C" fn mlirSparseTensorEncodingGetNumDimLevelTypes(
attr: MlirAttribute
) -> isizeReturns the number of dim level types in a sparse_tensor.encoding attribute.