pub unsafe extern "C" fn mlirSymbolTableGetSymbolAttributeName(
) -> MlirStringRefExpand description
Returns the name of the attribute used to store symbol names compatible with symbol tables.
pub unsafe extern "C" fn mlirSymbolTableGetSymbolAttributeName(
) -> MlirStringRefReturns the name of the attribute used to store symbol names compatible with symbol tables.