Function llvm_mlir_sys::mlirUnrankedTensorTypeGet
source · Expand description
Creates an unranked tensor type with the given element type in the same context as the element type. The type is owned by the context.
Creates an unranked tensor type with the given element type in the same context as the element type. The type is owned by the context.