Struct llvm_mlir_sys::MlirDiagnostic
source · Expand description
An opaque reference to a diagnostic, always owned by the diagnostics engine (context). Must not be stored outside of the diagnostic handler.
Fields
ptr: *mut c_voidTrait Implementations
sourceimpl Clone for MlirDiagnostic
impl Clone for MlirDiagnostic
sourcefn clone(&self) -> MlirDiagnostic
fn clone(&self) -> MlirDiagnostic
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more