Struct llvm_mlir_sys::MlirLogicalResult
source · #[repr(C)]pub struct MlirLogicalResult {
pub value: i8,
}Expand description
A logical result value, essentially a boolean with named states. LLVM convention for using boolean values to designate success or failure of an operation is a moving target, so MLIR opted for an explicit class. Instances of MlirLogicalResult must only be inspected using the associated functions.
Fields
value: i8Trait Implementations
sourceimpl Clone for MlirLogicalResult
impl Clone for MlirLogicalResult
sourcefn clone(&self) -> MlirLogicalResult
fn clone(&self) -> MlirLogicalResult
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more