Type Definition llvm_mlir_sys::MlirStringCallback

source ·
pub type MlirStringCallback = Option<unsafe extern "C" fn(arg1: MlirStringRef, arg2: *mut c_void)>;
A callback for returning string references.

This function is called back by the functions that need to return a reference to the portion of the string with the following arguments:

  • an MlirStringRef representing the current portion of the string
  • a pointer to user data forwarded from the printing call.