Struct llvm_mlir_sys::MlirOperationState
source · #[repr(C)]pub struct MlirOperationState {Show 13 fields
pub name: MlirStringRef,
pub location: MlirLocation,
pub nResults: isize,
pub results: *mut MlirType,
pub nOperands: isize,
pub operands: *mut MlirValue,
pub nRegions: isize,
pub regions: *mut MlirRegion,
pub nSuccessors: isize,
pub successors: *mut MlirBlock,
pub nAttributes: isize,
pub attributes: *mut MlirNamedAttribute,
pub enableResultTypeInference: bool,
}Expand description
An auxiliary class for constructing operations.
This class contains all the information necessary to construct the operation. It owns the MlirRegions it has pointers to and does not own anything else. By default, the state can be constructed from a name and location, the latter being also used to access the context, and has no other components. These components can be added progressively until the operation is constructed. Users are not expected to rely on the internals of this class and should use mlirOperationState* functions instead.
Fields
name: MlirStringReflocation: MlirLocationnResults: isizeresults: *mut MlirTypenOperands: isizeoperands: *mut MlirValuenRegions: isizeregions: *mut MlirRegionnSuccessors: isizesuccessors: *mut MlirBlocknAttributes: isizeattributes: *mut MlirNamedAttributeenableResultTypeInference: boolTrait Implementations
sourceimpl Clone for MlirOperationState
impl Clone for MlirOperationState
sourcefn clone(&self) -> MlirOperationState
fn clone(&self) -> MlirOperationState
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more